@@ -219,7 +219,7 @@ class AccessInfo(object):
 
         :returns: bool
         """
-        return self.project_scoped or self.domain_scoped
+        return self.project_scoped or self.domain_scoped or self.system_scoped
 
     @property
     def project_scoped(self):
@@ -237,6 +237,14 @@ class AccessInfo(object):
         """
         raise NotImplementedError()
 
+    @property
+    def system_scoped(self):
+        """Return true if the auth token was scoped to the system.
+
+        :returns: bool
+        """
+        raise NotImplementedError()
+
     @property
     def trust_id(self):
         """Return the trust id associated with the auth request.
@@ -491,6 +499,10 @@ class AccessInfoV2(AccessInfo):
     def domain_scoped(self):
         return False
 
+    @property
+    def system_scoped(self):
+        return False
+
     @property
     def _trust(self):
         return self._data['access']['trust']
@@ -647,6 +659,10 @@ class AccessInfoV3(AccessInfo):
     def username(self):
         return self._user['name']
 
+    @_missingproperty
+    def system(self):
+        return self._data['token']['system']
+
     @property
     def _domain(self):
         return self._data['token']['domain']
@@ -690,6 +706,10 @@ class AccessInfoV3(AccessInfo):
         except KeyError:
             return False
 
+    @_missingproperty
+    def system_scoped(self):
+        return self._data['token']['system'].get('all', False)
+
     @property
     def _trust(self):
         return self._data['token']['OS-TRUST:trust']
@@ -713,6 +733,18 @@ class AccessInfoV3(AccessInfo):
     def trustor_user_id(self):
         return self._trust['trustor_user']['id']
 
+    @property
+    def application_credential(self):
+        return self._data['token']['application_credential']
+
+    @_missingproperty
+    def application_credential_id(self):
+        return self._data['token']['application_credential']['id']
+
+    @_missingproperty
+    def application_credential_access_rules(self):
+        return self._data['token']['application_credential']['access_rules']
+
     @property
     def _oauth(self):
         return self._data['token']['OS-OAUTH1']
@@ -750,3 +782,11 @@ class AccessInfoV3(AccessInfo):
     @_missingproperty
     def bind(self):
         return self._data['token']['bind']
+
+    @property
+    def oauth2_credential(self):
+        return self._data['token']['oauth2_credential']
+
+    @_missingproperty
+    def oauth2_credential_thumbprint(self):
+        return self._data['token']['oauth2_credential']['x5t#S256']
